==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebRowSelectionEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowSelectionEventArgsDetailDescription } from "./WebRowSelectionEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebRowSelectionEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowSelectionEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowSelectionEventArgsDetailDescriptionMetadata.a == null) {
                WebRowSelectionEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowSelectionEventArgsDetailDescriptionMetadata.c(WebRowSelectionEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebRowSelectionEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebRowSelectionEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:RowSelectionEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("OldSelectionRef", "(w:OldSelection,wf:OldSelection)DataRef:object");
            a.item("NewSelectionRef", "(w:NewSelection,wf:NewSelection)DataRef:object");
            a.item("AddedRef", "(w:Added,wf:Added)DataRef:object");
            a.item("RemovedRef", "(w:Removed,wf:Removed)DataRef:object");
            a.item("AllRowsSelected", "Boolean");
        }
        static d(a) {
            WebRowSelectionEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebRowSelectionEventArgsDetail", () => new WebRowSelectionEventArgsDetailDescription());
            a.ac("WebRowSelectionEventArgsDetail", WebRowSelectionEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebRowSelectionEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRowSelectionEventArgsDetailDescriptionMetadata, 'WebRowSelectionEventArgsDetailDescriptionMetadata');
    WebRowSelectionEventArgsDetailDescriptionMetadata.a = null;
    return WebRowSelectionEventArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebRowSelectionEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowSelectionEventArgsDetailDescription } from "./WebRowSelectionEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebRowSelectionEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowSelectionEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowSelectionEventArgsDetailDescriptionMetadata.a == null) {
                WebRowSelectionEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowSelectionEventArgsDetailDescriptionMetadata.c(WebRowSelectionEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebRowSelectionEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebRowSelectionEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RowSelectionEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("OldSelectionRef", "(w:OldSelection,wf:OldSelection)DataRef:object");
            a.item("NewSelectionRef", "(w:NewSelection,wf:NewSelection)DataRef:object");
            a.item("AddedRef", "(w:Added,wf:Added)DataRef:object");
            a.item("RemovedRef", "(w:Removed,wf:Removed)DataRef:object");
            a.item("AllRowsSelected", "Boolean");
            a.item("Cancel", "Boolean");
            a.item("Owner", "Unknown");
        }
        static d(a) {
            WebRowSelectionEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebRowSelectionEventArgsDetail", () => new WebRowSelectionEventArgsDetailDescription());
            a.ad("WebRowSelectionEventArgsDetail", WebRowSelectionEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebRowSelectionEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRowSelectionEventArgsDetailDescriptionMetadata, 'WebRowSelectionEventArgsDetailDescriptionMetadata');
    WebRowSelectionEventArgsDetailDescriptionMetadata.a = null;
    return WebRowSelectionEventArgsDetailDescriptionMetadata;
})();
